@@ -88,11 +88,11 @@ Watch the notification appear in the corresponding Slack channel(s):
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.0.2
 
 =cut
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 
 
 =head1 CONFIGURATION OPTIONS
@@ -218,7 +218,7 @@ sub run_pre_push
 		notify_slack(
 			$app,
 			sprintf(
-				"\@channel - Release %s of %s:\n%s",
+				"*Release %s of %s:*\n%s",
 				$tag,
 				$remote_name,
 				$serialized_notes,
